/*jslint plusplus:false,white:false,undef: false, rhino: true, onevar: true, evil: false */
/*
Title: Eventos

Arquivo:

i3geo/classesjs/classe_eventos.js

Licenca:

GPL2

I3Geo Interface Integrada de Ferramentas de Geoprocessamento para Internet

Direitos Autorais Reservados (c) 2006 Ministrio do Meio Ambiente Brasil
Desenvolvedor: Edmar Moretti edmar.moretti@mma.gov.br

Este programa  software livre; voc pode redistribu-lo
e/ou modific-lo sob os termos da Licena Pblica Geral
GNU conforme publicada pela Free Software Foundation;

Este programa  distribudo na expectativa de que seja til,
porm, SEM NENHUMA GARANTIA; nem mesmo a garantia implcita
de COMERCIABILIDADE OU ADEQUAO A UMA FINALIDADE ESPECFICA.
Consulte a Licena Pblica Geral do GNU para mais detalhes.
Voc deve ter recebido uma cpia da Licena Pblica Geral do
GNU junto com este programa; se no, escreva para a
Free Software Foundation, Inc., no endereo
59 Temple Street, Suite 330, Boston, MA 02111-1307 USA.
*/
if(typeof(i3GEO) === 'undefined'){
	i3GEO = [];
}
objposicaocursor = {
	ddx: "",
	ddy: "",
	dmsx: "",
	dmsy: "",
	telax: "",
	telay: "",
	imgx: "",
	imgy: "",
	refx: "",
	refy: ""
};
/*
Classe: i3GEO.eventos

Controla as operaes que so executadas em eventos que ocorrem no mapa.

As listas de operaes consistem em variveis com nomes de funes.

As listas so inicializadas com algunmas funes j embutidas, mas podem ser acrescentadas outras.

Exemplos:

	Para incluir uma funo em um determinado evento utilize

	if(i3GEO.eventos.NAVEGAMAPA.toString().search("i3GEO.gadgets.atualizaEscalaNumerica()") < 0)

	{i3GEO.eventos.NAVEGAMAPA.push("i3GEO.gadgets.atualizaEscalaNumerica()");}

	Para remover utilize

	i3GEO.eventos.NAVEGAMAPA.remove("i3GEO.gadgets.atualizaEscalaNumerica()");
*/
i3GEO.eventos = {
	/*
	Propriedade: ATUALIZAARVORECAMADAS

	Armazena as funes (eventos) que sero executadas quando a rvore de camadas for atualizada.

	Tipo:
	{Array}
	*/
	ATUALIZAARVORECAMADAS: [],
	/*
	Propriedade: ATIVATEMA

	Armazena as funes (eventos) que sero executadas quando um tema da rvore de camadas  ativado.

	Tipo:
	{Array}
	*/
	ATIVATEMA: [],
	/*
	Propriedade: NAVEGAMAPA

	Armazena as funes que sero executadas quando  feita uma operao de navegao sobre o mapa.

	Tipo:
	{Array}
	*/
	NAVEGAMAPA: [],
	/*
	Propriedade: MOUSEPARADO

	Armazena as funes que sero executadas quando o usurio estaciona o mouse sobre o mapa 
	por alguns instantes.

	Tipo:
	{Array}

	Default:
	{["i3GEO.navega.mostraRosaDosVentos()"]}
	*/
	MOUSEPARADO: ["i3GEO.navega.mostraRosaDosVentos()"],
	/*
	Propriedade: MOUSEMOVE

	Armazena as funes que sero executadas quando o usurio move o mouse sobre o mapa 

	Tipo:
	{Array}

	Default:
	{[]}
	*/
	MOUSEMOVE: [],
	/*
	Propriedade: MOUSEDOWN

	Armazena as funes que sero executadas quando o usurio pressiona o boto do mouse sobre o mapa 

	Tipo:
	{Array}

	Default:
	{[]}
	*/
	MOUSEDOWN: [],
	/*
	Propriedade: MOUSEUP

	Armazena as funes que sero executadas quando o usurio solta o boto do mouse sobre o mapa 

	Tipo:
	{Array}

	Default:
	{[]}
	*/
	MOUSEUP: [],
	/*
	Propriedade: MOUSECLIQUE

	Armazena as funes que sero executadas quando o usurio clica sobre o mapa 

	Tipo:
	{Array}

	Default:
	{["i3GEO.eventos.cliqueCapturaPt()"]}
	*/
	MOUSECLIQUE: ["i3GEO.eventos.cliqueCapturaPt()"],
	/*
	Variavel: TIMERPARADO

	Timer utilizado pelo contador do mouse parado

	Tipo:
	{Timeout}
	*/
	TIMERPARADO: "",
	/*
	Function: mouseParado

	Executa as funes definidas em MOUSEPARADO quando  detectado que o mouse est estacionado.

	A execuo desse evento  controlado por um timer definido no evento onmousemove (sobre o mapa).

	*/
	mouseParado: function()	{
		if(typeof(console) !== 'undefined'){console.info("i3GEO.eventos.mouseParado()");}
		try
		{clearTimeout(this.TIMERPARADO);}
		catch(e){this.TIMERPARADO = "";}
		if(objposicaocursor.dentroDomapa === false){return;}
		try{
			if(objposicaocursor.imgy === ""){
				objposicaocursor.imgy = 1;
				objposicaocursor.imgx = 1;
			}
			if (i3GEO.eventos.MOUSEPARADO.length > 0 && objposicaocursor.imgy > 0 && objposicaocursor.imgx > 0){
				if(objposicaocursor.imgx > 0){
					i3GEO.eventos.executaEventos(i3GEO.eventos.MOUSEPARADO);
				}
			}
		}catch(e){
			if(typeof(console) !== 'undefined'){console.error(e);}
		}
	},
	/*
	Function: navegaMapa

	Executa as funes armazenadas em NAVEGAMAPA, ou seja, operaes executadas quando o mapa tem sua extenso geogrfica alterada.
	*/
	navegaMapa: function(){
		if(typeof(console) !== 'undefined'){console.info("i3GEO.eventos.navegaMapa()");}
		i3GEO.eventos.executaEventos(this.NAVEGAMAPA);
	},
	/*
	Function: mousemoveMapa

	Executa as funes armazenadas em MOUSEMOVE.
	*/
	mousemoveMapa: function(){
		i3GEO.eventos.executaEventos(this.MOUSEMOVE);
	},
	/*
	Function: mousedownMapa

	Executa as funes armazenadas em MOUSEDOWN.
	*/
	mousedownMapa: function(){
		if(typeof(console) !== 'undefined'){console.info("i3GEO.eventos.mousedownMapa()");}
		i3GEO.eventos.executaEventos(this.MOUSEDOWN);
	},
	/*
	Function: mouseupMapa

	Executa as funes armazenadas em MOUSEUP.
	*/
	mouseupMapa: function(){
		if(typeof(console) !== 'undefined'){console.info("i3GEO.eventos.mouseupMapa()");}
		i3GEO.eventos.executaEventos(this.MOUSEUP);
	},
	/*
	Function: mousecliqueMapa

	Executa as funes armazenadas em MOUSECLIQUE.
	*/
	mousecliqueMapa: function(){
		if(typeof(console) !== 'undefined'){console.info("i3GEO.eventos.mousecliqueMapa()");}
		i3GEO.eventos.executaEventos(this.MOUSECLIQUE);
	},
	/*
	Function: executaEventos

	Executa a pilha de nomes de funes armazenados em um array

	Parameter:

	eventos {array} - array com os nomes das funes
	*/
	executaEventos: function(eventos){
		var f,temp;
		try{
			if (eventos.length > 0){
				f = eventos.length-1;
				if (f >= 0){
					do{
						if(eventos[f] !== "")
						{eval(eventos[f]);}
					}
					while(f--);
				}
			}
		}
		catch(e){
			if(typeof(console) !== 'undefined'){console.error(e);}
			eventos[f] = "";
		}
	},
	/*
	Function posicaoMouseMapa

	Captura a posio do mouse sobre um mapa. O clculo pode ser feito sobre o corpo do mapa principal ou sob o corpo do mapa de referncia

	O resultado dos clculos so armazenados no objeto objposicaocursor
	esse objeto ter as seguintes propriedades:

			objposicaocursor.ddx valor de x em dcimos de grau

			objposicaocursor.ddy valor de y em dcimos de grau

			objposicaocursor.dmsx valor de x em dms

			objposicaocursor.dmsy valor de y em dms

			objposicaocursor.telax posicao x na tela em pixels

			objposicaocursor.telay posicao y na tela em pixels

			objposicaocursor.imgx posicao x no mapa em pixels

			objposicaocursor.imgy: posicao y no mapa em pixels

			objposicaocursor.refx: posicao x no mapa de referncia em pixels

			objposicaocursor.refy: posicao x no mapa de referncia em pixels

	Parameters:

	e {Event object} - objeto do tipo evento disparado sobre o objeto em foco
	*/
	posicaoMouseMapa: function(e){
		//
		//os eventos da interface googlemaps so definidos em i3GEO.Interface
		//se a interface for googleearth, googlemaps ou openlayers, os eventos so controlados
		//pelas respectivas apis
		//caso contrrio, o i3geo ir controlar os clculos
		//Entretanto, nas ferramentas que usam o richdraw (distncia e rea) o posicionamento
		//deve ser controlado pelo i3geo
		//
		var teladd,teladms,container,targ,pos,mousex,mousey,xfig,yfig,xreffig,yreffig,xtela,ytela,c,ex,r;
		if (!e){e = window.event;}
		try{
			if (e.target)
			{targ = e.target;}
			else
			if (e.srcElement)
			{targ = e.srcElement;}
			container = targ.parentNode.id;
		}
		catch(erro){
			if(typeof(console) !== 'undefined'){console.error(erro);}
		}
		if (container !== "divGeometriasTemp" && container !== "mapaReferencia"){
			if(i3GEO.util.in_array(i3GEO.Interface.ATUAL,["googlemaps","googleearth","openlayers"]))
			{return;}
		}

		//
		//verifica sob qual objeto o mouse est se movendo
		//
		if (e.target)
		{targ = e.target;}
		else if (e.srcElement) {targ = e.srcElement;}
		if(targ.id === "" && $i(i3GEO.Interface.IDMAPA))
		{targ = $i(i3GEO.Interface.IDMAPA);}
		//
		//se estiver no modo pan, o movimento deve ser obtido do elemento
		//onde est a imagem do mapa e no diretamente sobre o elemento 'img'
		//se no for feito assim, o deslocamento do mapa no  capturado
		//
		try{
			if(g_panM !== 'undefined' && g_panM === "sim")
			{pos = i3GEO.util.pegaPosicaoObjeto(targ.parentNode);}
			else
			{pos = i3GEO.util.pegaPosicaoObjeto(targ);}
			if((i3GEO.configura.entorno.toLowerCase() === "sim") && (g_panM === "sim")){
				pos[0] = pos[0] - i3GEO.parametros.w;
				pos[1] = pos[1] - i3GEO.parametros.h;
			}
		}
		catch(m){pos = i3GEO.util.pegaPosicaoObjeto(targ);}
		//
		//pega a posicao correta do mouse
		//
		mousex = 0;
		mousey = 0;
		if (e.pageX || e.pageY){
			mousex = e.pageX;
			mousey = e.pageY;
		}
		else if (e.clientX || e.clientY){
			mousex = e.clientX + document.body.scrollLeft + document.documentElement.scrollLeft;
			mousey = e.clientY + document.body.scrollTop + document.documentElement.scrollTop;
		}
		//
		//faz os clculos de posicionamento
		//fig e reffig so a mesma coisa por enquanto
		//
		xfig = mousex - pos[0];
		yfig = mousey - pos[1];
		xreffig = xfig;
		yreffig = yfig;
		xtela = mousex;
		ytela = mousey;
		//
		//celula e extent so necessrios para se fazer a
		//converso de coordenadas de tela para coordenadas geogrficas
		//esses valores so obtidos das funes ajax que redesenham ou inicializam o mapa
		// 
		c = i3GEO.parametros.pixelsize;
		ex = i3GEO.parametros.mapexten;
		try{
			if(targ.id === "imagemReferencia"){
				c = i3GEO.parametros.celularef;
				ex = i3GEO.parametros.extentref;
				r = $i("i3geo_rosa");
				if(r)
				{r.style.display = "none";}
			}
		}
		catch(e){i3GEO.parametros.celularef = 0;}
		//if(typeof(console) !== 'undefined'){console.error(xfig);}
		teladd = i3GEO.calculo.tela2dd(xfig,yfig,c,ex,targ.id);
		teladms = i3GEO.calculo.dd2dms(teladd[0],teladd[1]);

		objposicaocursor = {
			ddx: teladd[0],
			ddy: teladd[1],
			dmsx: teladms[0],
			dmsy: teladms[1],
			telax: xtela,
			telay: ytela,
			imgx: xfig,
			imgy: yfig,
			refx: xreffig,
			refy: yreffig,
			dentroDomapa: true
		};
	},
	/*
	Function: ativa

	Ativa os eventos relacionados ao mapa (movimentao do mouse sobre o mapa)

	Define o que ser executado quando o mouse  clicado ou movido sobre o mapa.

	Alm das funes padro,so ativadas aquelas definidas nas variveis de configurao (veja classe_configura.js)

	Parametro:

	docMapa {DOM node} - objeto que ser alvo da ativao dos cliques
	*/
	ativa: function(docMapa){
		if(typeof(console) !== 'undefined'){console.info("i3GEO.eventos.ativa()");}
		docMapa.onmouseover = function(){
			objposicaocursor.dentroDomapa = true;
			this.onmousemove=function(exy){
				//var executar = new Function("i3GEO.eventos.mouseParado().call");
				i3GEO.eventos.posicaoMouseMapa(exy);
				try{
					try
					{clearTimeout(i3GEO.eventos.TIMERPARADO);}
					catch(e){
						if(typeof(console) !== 'undefined'){console.error(e);}
					}
					i3GEO.eventos.TIMERPARADO = setTimeout(function(){i3GEO.eventos.mouseParado();},i3GEO.configura.tempoMouseParado);
				}
				catch(e){
					if(typeof(console) !== 'undefined'){console.error(e);}
				}
				try
				{i3GEO.eventos.mousemoveMapa();}
				catch(e){
					if(typeof(console) !== 'undefined'){console.error(e);}
				}
			};
		};
		docMapa.onmouseout = function(){
			objposicaocursor.dentroDomapa = true;
			try
			{objmapaparado="parar";}
			catch(e){
				if(typeof(console) !== 'undefined'){console.error(e);}
			}
		};
		docMapa.onmousedown = function(exy){
			if(!i3GEO.eventos.botaoDireita(exy))
			{i3GEO.eventos.mousedownMapa();}
		};
		docMapa.onclick = function(exy){
			if(!i3GEO.eventos.botaoDireita(exy))
			{i3GEO.eventos.mousecliqueMapa();}
		};
		docMapa.onmouseup = function(exy){
			if(!i3GEO.eventos.botaoDireita(exy))
			{i3GEO.eventos.mouseupMapa();}
		};
	},
	/*
	Function: botaoDireita

	Retorna true se o boto da direita foi utilizado no evento do mouse

	Parametro:

	exy - evento

	Return:
	{boolean}
	*/
	botaoDireita: function(exy){
		try{
			var k = (navm) ? event.button : exy.button;
			if(k !== 2)
			{return false;}
			else
			{return true;}
		}
		catch(e){return false;}
	},
	/*
	Function: cliqueCapturaPt

	Captura um ponto na tela e retorna o resultado para a janela interna que estiver aberta.

	As coordenadas do ponto, em DMS, so repassadas para os campos do tipo input da janela interna que estiver aberta.
	A janela aberta deve ter os seguintes elementos do tipo input (ids):
	ixg,ixm,ixs,iyg,iym,iys
	*/
	cliqueCapturaPt: function(ixg,ixm,ixs,iyg,iym,iys){
		if(typeof(console) !== 'undefined'){console.info("i3GEO.eventos.cliqueCapturaPt()");}
		var x,y,doc;
		if(arguments.length === 0){
			ixg = "ixg";
			ixm = "ixm";
			ixs = "ixs";
			iyg = "iyg";
			iym = "iym";
			iys = "iys";
			if($i("wdocai"))
			{doc = (navm) ? document.frames("wdocai").document : $i("wdocai").contentDocument;}
		}
		else{
			doc = document;
		}
		if (g_tipoacao !== "capturaponto"){return;}
		else{
			try{
				if(doc){
					x = objposicaocursor.dmsx.split(" ");
					y = objposicaocursor.dmsy.split(" ");
					if (doc.getElementById(ixg))
					{doc.getElementById(ixg).value = x[0];}
					if (doc.getElementById(ixm))
					{doc.getElementById(ixm).value = x[1];}
					if (doc.getElementById(ixs))
					{doc.getElementById(ixs).value = x[2];}
					if (doc.getElementById(iyg))
					{doc.getElementById(iyg).value = y[0];}
					if (doc.getElementById(iym))
					{doc.getElementById(iym).value = y[1];}
					if (doc.getElementById(iys))
					{doc.getElementById(iys).value = y[2];}
				}
			}
			catch(m){
				if(typeof(console) !== 'undefined'){console.error(m);}
			}
		}
	}
};
//YAHOO.log("carregou classe eventos", "Classes i3geo");